@@ -105,22 +105,3 @@ def compare_files(source_file, target_file, _):
         "source_file": source_file_results,
         "target_file": target_file_results
     }
-
-
-raw_code = """
-def resumen_de_pedidos(lista_pedidos):
-    '''Recibe una lista de diccionarios, cada diccionario con sus 
-    propios productos y cantidades, y escribe un archivo
-    con el resumen de los pedidos'''
-    resumen = {}
-    with open('resumen_pedidos.txt', 'w') as archivo:
-
-        for resumen_por_cliente in lista_pedidos:
-            for producto, cantidad in resumen_por_cliente.items():
-                resumen[producto] = resumen.get(producto, 0) + int(cantidad)
-
-        for nombre_producto, cant_total in resumen.items():
-            archivo.write(f'{nombre_producto};{cant_total}\n')
-"""
-
-get_fingerprints_2(raw_code)
